const express = require('express');
const morgan = require('morgan');
const errHandler = require('errorhandler');
const path = require('path');
const router = require('./router');
var session = require('express-session');
var MongoDBStore = require('connect-mongodb-session')(session);
const app = express();

// 打印服务端日志
app.use(morgan('dev'));

app.use('/public', express.static(path.join(__dirname, 'public')));
app.use('/node_modules', express.static(path.join(__dirname, 'node_modules')));

// 配置render引擎
app.engine('html', require('express-art-template'));
app.set('views', {
    debug: process.env.NODE_ENV !== 'production'
});
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'html');

// session数据持久化
var store = new MongoDBStore({
  uri: 'mongodb://localhost:27017/sessionDatabase',
  collection: 'sessions'
});

app.use(session({
  secret: 'keyboard cat',
  resave: false,
  saveUninitialized: true,
  cookie: { 
    // secure: true,
    maxAge: 1000 * 60 * 60 * 24 * 7 // 1 week
  },
  store: store
}))

app.use(router)

// 错误处理中间件
if (process.env.NODE_ENV === 'development') {
  app.use(errHandler())
}

const PORT = process.env.PORT || 3000;

app.listen(PORT, () => console.log('服务已启动，运行在http://localhost:' + PORT));